package Method::Workflow::Case::Action;
use strict;
use warnings;
use Method::Workflow::SubClass;

keyword 'action';

1;
